@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
 
 """Tests for the class resolver."""
-
+import itertools
 import unittest
 
 from class_resolver import Resolver
 
+try:
+    import ray.tune as tune
+except ImportError:
+    tune = None
+
 
 class Base:
     """A base class."""
@@ -55,3 +60,20 @@ class TestResolver(unittest.TestCase):
         """Test instances are passed through unmodified."""
         a = A(name='charlie')
         self.assertEqual(a, self.resolver.make(a))
+
+    @unittest.skipIf(tune is None, 'ray[tune] was not installed properly')
+    def test_variant_generation(self):
+        """Test whether ray tune can generate variants from the search space."""
+        search_space = self.resolver.ray_tune_search_space(
+            kwargs_search_space=dict(
+                name=tune.choice(["charlie", "max"]),
+            ),
+        )
+        for spec in itertools.islice(tune.suggest.variant_generator.generate_variants(search_space), 2):
+            config = {
+                k[0]: v
+                for k, v in spec[0].items()
+            }
+            query = config.pop("query")
+            instance = self.resolver.make(query=query, pos_kwargs=config)
+            self.assertIsInstance(instance, Base)
